==> umya-spreadsheet-0.4.1.crate: umya-spreadsheet-0.4.1/src/structs.rs <==
//! store structs.

pub mod drawing;

          mod spreadsheet;
pub use self::spreadsheet::*;

          mod worksheet;
pub use self::worksheet::*;

          mod properties;
pub use self::properties::*;

          mod cell;
pub use self::cell::*;

          mod cells;
pub use self::cells::*;

          mod hyperlink;
pub use self::hyperlink::*;

          mod shadow;
pub use self::shadow::*;

          mod color;
pub use self::color::*;

          mod page_setup;
pub use self::page_setup::*;

          mod page_margins;
pub use self::page_margins::*;

          mod header_footer;
pub use self::header_footer::*;

          mod header_footer_drawing;
pub use self::header_footer_drawing::*;

          mod sheet_view;
pub use self::sheet_view::*;

          mod auto_filter;
pub use self::auto_filter::*;

          mod column;
pub use self::column::*;

          mod security;
pub use self::security::*;

          mod calculation;
pub use self::calculation::*;

          mod style;
pub use self::style::*;

          mod font;
pub use self::font::*;

          mod fill;
pub use self::fill::*;

                 mod borders;
pub(crate) use self::borders::*;

          mod border;
pub use self::border::*;

          mod alignment;
pub use self::alignment::*;

          mod conditional;
pub use self::conditional::*;

          mod protection;
pub use self::protection::*;

          mod rich_text;
pub use self::rich_text::*;

          mod text_element;
pub use self::text_element::*;

          mod picture;
pub use self::picture::*;

          mod theme;
pub use self::theme::*;

          mod cell_style;
pub use self::cell_style::*;

          mod defined_name;
pub use self::defined_name::*;

          mod comment;
pub use self::comment::*;

          mod coordinate;
pub use self::coordinate::*;

          mod range;
pub use self::range::*;

          mod conditional_set;
pub use self::conditional_set::*;

          mod address;
pub use self::address::*;

          mod anchor;
pub use self::anchor::*;

          mod alternate_content;
pub use self::alternate_content::*;

          mod alternate_content_choice;
pub use self::alternate_content_choice::*;

          mod alternate_content_fallback;
pub use self::alternate_content_fallback::*;

          mod office2010;
pub use self::office2010::*;

          mod boolean_value;
pub use self::boolean_value::*;

          mod u_int32_value;
pub use self::u_int32_value::*;

          mod u_int16_value;
pub use self::u_int16_value::*;

          mod int32_value;
pub use self::int32_value::*;

          mod int16_value;
pub use self::int16_value::*;

          mod string_value;
pub use self::string_value::*;

          mod double_value;
pub use self::double_value::*;

          mod enum_value;
pub use self::enum_value::*;

          mod enum_trait;
pub use self::enum_trait::*;

          mod byte_value;
pub use self::byte_value::*;

          mod s_byte_value;
pub use self::s_byte_value::*;

          mod int64_value;
pub use self::int64_value::*;

          mod row;
pub use self::row::*;

          mod font_name;
pub use self::font_name::*;

          mod font_size;
pub use self::font_size::*;

          mod font_family_numbering;
pub use self::font_family_numbering::*;

          mod bold;
pub use self::bold::*;

          mod italic;
pub use self::italic::*;

          mod underline_values;
pub use self::underline_values::*;

          mod underline;
pub use self::underline::*;

          mod strike;
pub use self::strike::*;

          mod font_char_set;
pub use self::font_char_set::*;

          mod font_scheme_values;
pub use self::font_scheme_values::*;

          mod font_scheme;
pub use self::font_scheme::*;

          mod fonts;
pub use self::fonts::*;

          mod pattern_fill;
pub use self::pattern_fill::*;

          mod pattern_values;
pub use self::pattern_values::*;

          mod fills;
pub use self::fills::*;

          mod numbering_format;
pub use self::numbering_format::*;

          mod numbering_formats;
pub use self::numbering_formats::*;

          mod stylesheet;
pub use self::stylesheet::*;

          mod border_properties_type;
pub use self::border_properties_type::*;

          mod border_style_values;
pub use self::border_style_values::*;

          mod borders_crate;
pub use self::borders_crate::*;

          mod cell_format;
pub use self::cell_format::*;

          mod horizontal_alignment_values;
pub use self::horizontal_alignment_values::*;

          mod vertical_alignment_values;
pub use self::vertical_alignment_values::*;

          mod cell_formats;
pub use self::cell_formats::*;

          mod cell_style_formats;
pub use self::cell_style_formats::*;

          mod cell_styles;
pub use self::cell_styles::*;

          mod differential_format;
pub use self::differential_format::*;

          mod differential_formats;
pub use self::differential_formats::*;

          mod mru_colors;
pub use self::mru_colors::*;

          mod colors;
pub use self::colors::*;

          mod shared_string_table;
pub use self::shared_string_table::*;

          mod shared_string_item;
pub use self::shared_string_item::*;

          mod text;
pub use self::text::*;

          mod phonetic_run;
pub use self::phonetic_run::*;

          mod gradient_fill;
pub use self::gradient_fill::*;

          mod gradient_stop;
pub use self::gradient_stop::*;

          mod vertical_alignment_run_values;
pub use self::vertical_alignment_run_values::*;

          mod vertical_text_alignment;
pub use self::vertical_text_alignment::*;

          mod cell_value;
pub use self::cell_value::*;

          mod row_reference;
pub use self::row_reference::*;

          mod column_reference;
pub use self::column_reference::*;

          mod columns;
pub use self::columns::*;

          mod column_sort;
pub use self::column_sort::*;

          mod sequence_of_references;
pub use self::sequence_of_references::*;

          mod selection;
pub use self::selection::*;

          mod pane_values;
pub use self::pane_values::*;

          mod pane;
pub use self::pane::*;

          mod pane_state_values;
pub use self::pane_state_values::*;

          mod workbook_view;
pub use self::workbook_view::*;

==> umya-spreadsheet-0.4.2.crate: umya-spreadsheet-0.4.2/src/structs.rs <==
//! store structs.

pub mod drawing;

          mod spreadsheet;
pub use self::spreadsheet::*;

          mod worksheet;
pub use self::worksheet::*;

          mod properties;
pub use self::properties::*;

          mod cell;
pub use self::cell::*;

          mod cells;
pub use self::cells::*;

          mod hyperlink;
pub use self::hyperlink::*;

          mod shadow;
pub use self::shadow::*;

          mod color;
pub use self::color::*;

          mod page_setup;
pub use self::page_setup::*;

          mod page_margins;
pub use self::page_margins::*;

          mod header_footer;
pub use self::header_footer::*;

          mod header_footer_drawing;
pub use self::header_footer_drawing::*;

          mod sheet_view;
pub use self::sheet_view::*;

          mod auto_filter;
pub use self::auto_filter::*;

          mod column;
pub use self::column::*;

          mod security;
pub use self::security::*;

          mod calculation;
pub use self::calculation::*;

          mod style;
pub use self::style::*;

          mod font;
pub use self::font::*;

          mod fill;
pub use self::fill::*;

                 mod borders;
pub(crate) use self::borders::*;

          mod border;
pub use self::border::*;

          mod alignment;
pub use self::alignment::*;

          mod conditional;
pub use self::conditional::*;

          mod protection;
pub use self::protection::*;

          mod rich_text;
pub use self::rich_text::*;

          mod text_element;
pub use self::text_element::*;

          mod picture;
pub use self::picture::*;

          mod theme;
pub use self::theme::*;

          mod cell_style;
pub use self::cell_style::*;

          mod defined_name;
pub use self::defined_name::*;

          mod comment;
pub use self::comment::*;

          mod coordinate;
pub use self::coordinate::*;

          mod range;
pub use self::range::*;

          mod conditional_set;
pub use self::conditional_set::*;

          mod address;
pub use self::address::*;

          mod anchor;
pub use self::anchor::*;

          mod alternate_content;
pub use self::alternate_content::*;

          mod alternate_content_choice;
pub use self::alternate_content_choice::*;

          mod alternate_content_fallback;
pub use self::alternate_content_fallback::*;

          mod office2010;
pub use self::office2010::*;

          mod boolean_value;
pub use self::boolean_value::*;

          mod u_int32_value;
pub use self::u_int32_value::*;

          mod u_int16_value;
pub use self::u_int16_value::*;

          mod int32_value;
pub use self::int32_value::*;

          mod int16_value;
pub use self::int16_value::*;

          mod string_value;
pub use self::string_value::*;

          mod double_value;
pub use self::double_value::*;

          mod enum_value;
pub use self::enum_value::*;

          mod enum_trait;
pub use self::enum_trait::*;

          mod byte_value;
pub use self::byte_value::*;

          mod s_byte_value;
pub use self::s_byte_value::*;

          mod int64_value;
pub use self::int64_value::*;

          mod row;
pub use self::row::*;

          mod font_name;
pub use self::font_name::*;

          mod font_size;
pub use self::font_size::*;

          mod font_family_numbering;
pub use self::font_family_numbering::*;

          mod bold;
pub use self::bold::*;

          mod italic;
pub use self::italic::*;

          mod underline_values;
pub use self::underline_values::*;

          mod underline;
pub use self::underline::*;

          mod strike;
pub use self::strike::*;

          mod font_char_set;
pub use self::font_char_set::*;

          mod font_scheme_values;
pub use self::font_scheme_values::*;

          mod font_scheme;
pub use self::font_scheme::*;

          mod fonts;
pub use self::fonts::*;

          mod pattern_fill;
pub use self::pattern_fill::*;

          mod pattern_values;
pub use self::pattern_values::*;

          mod fills;
pub use self::fills::*;

          mod numbering_format;
pub use self::numbering_format::*;

          mod numbering_formats;
pub use self::numbering_formats::*;

          mod stylesheet;
pub use self::stylesheet::*;

          mod border_properties_type;
pub use self::border_properties_type::*;

          mod border_style_values;
pub use self::border_style_values::*;

          mod borders_crate;
pub use self::borders_crate::*;

          mod cell_format;
pub use self::cell_format::*;

          mod horizontal_alignment_values;
pub use self::horizontal_alignment_values::*;

          mod vertical_alignment_values;
pub use self::vertical_alignment_values::*;

          mod cell_formats;
pub use self::cell_formats::*;

          mod cell_style_formats;
pub use self::cell_style_formats::*;

          mod cell_styles;
pub use self::cell_styles::*;

          mod differential_format;
pub use self::differential_format::*;

          mod differential_formats;
pub use self::differential_formats::*;

          mod mru_colors;
pub use self::mru_colors::*;

          mod colors;
pub use self::colors::*;

          mod shared_string_table;
pub use self::shared_string_table::*;

          mod shared_string_item;
pub use self::shared_string_item::*;

          mod text;
pub use self::text::*;

          mod phonetic_run;
pub use self::phonetic_run::*;

          mod gradient_fill;
pub use self::gradient_fill::*;

          mod gradient_stop;
pub use self::gradient_stop::*;

          mod vertical_alignment_run_values;
pub use self::vertical_alignment_run_values::*;

          mod vertical_text_alignment;
pub use self::vertical_text_alignment::*;

          mod cell_value;
pub use self::cell_value::*;

          mod row_reference;
pub use self::row_reference::*;

          mod column_reference;
pub use self::column_reference::*;

          mod columns;
pub use self::columns::*;

          mod column_sort;
pub use self::column_sort::*;

          mod sequence_of_references;
pub use self::sequence_of_references::*;

          mod selection;
pub use self::selection::*;

          mod pane_values;
pub use self::pane_values::*;

          mod pane;
pub use self::pane::*;

          mod pane_state_values;
pub use self::pane_state_values::*;

          mod workbook_view;
pub use self::workbook_view::*;

          mod ole_objects;
pub use self::ole_objects::*;

          mod ole_object;
pub use self::ole_object::*;

          mod embedded_object_properties;
pub use self::embedded_object_properties::*;

          mod object_anchor;
pub use self::object_anchor::*;

          mod from_marker;
pub use self::from_marker::*;

          mod to_marker;
pub use self::to_marker::*;

          mod reader_writer_trait;
pub use self::reader_writer_trait::*;
